@@ -27,7 +27,6 @@
 #include <QGridLayout>
 
 #include <KLocalizedString>
-#include <KGlobal>
 #include <KDialog>
 #include <KKeySequenceWidget>
 #include <KLineEdit>
@@ -43,10 +42,8 @@
 #include "klinespellchecking.h"
 #include "menuinfo.h"
 
-#include "basictab.moc"
-
 BasicTab::BasicTab( QWidget *parent )
-    : KTabWidget(parent)
+    : QTabWidget(parent)
 {
     _menuFolderInfo = 0;
     _menuEntryInfo = 0;
